<?php

namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use \Elementor\Core\Schemes\Typography;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevs_analysis_tab  extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'analysis_tab_widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Analysis Tab', 'bdevs-elementor');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-slideshow';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['bdevs-elementor'];
	}

	public function get_keywords()
	{
		return ['analysis'];
	}

	public function get_script_depends()
	{
		return ['bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position()
	{
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor'),
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor'),
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor'),
			'center'        => esc_html__('Center', 'bdevs-elementor'),
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor'),
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor'),
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor'),
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor'),
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor'),
		];

		return $position_options;
	}

	// register_controls
	protected function register_controls()
	{
		$this->register_content_controls();
		$this->register_style_controls();
	}

	// register_content_controls
	protected function register_content_controls()
	{
		$this->start_controls_section(
			'section_content_wedo',
			[
				'label' => esc_html__('Analysis Tab', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'analysis_tabs',
			[
				'label' => esc_html__('Analysis Tab Items', 'bdevs-elementor'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__('Analysis #1', 'bdevs-elementor'),
						'tab_content' => esc_html__('I am item content. Click edit button to change this text.', 'bdevs-elementor'),
					],
					[
						'tab_title'   => esc_html__('Analysis #1', 'bdevs-elementor'),
						'tab_content' => esc_html__('I am item content. Click edit button to change this text.', 'bdevs-elementor'),
					]
				],
				'fields' => [
					[
						'name'        => 'analysis_menu',
						'label'       => esc_html__('Analysis Menu', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('Industry analysis', 'bdevs-elementor'),
						'label_block' => true,
					],
					[
						'name'    => 'tab_image_icon',
						'label'   => esc_html__('Tab Icon Image', 'bdevs-elementor'),
						'type'    => Controls_Manager::MEDIA,
						'default' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'dynamic' => ['active' => true],
					],
					[
						'name'        => 'tab_sub_title',
						'label'       => esc_html__('Sub Title', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('Its Sub Title', 'bdevs-elementor'),
						'label_block' => true,
					],
					[
						'name'        => 'tab_title',
						'label'       => esc_html__('Title', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('Its Title', 'bdevs-elementor'),
						'label_block' => true,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__('Image', 'bdevs-elementor'),
						'type'    => Controls_Manager::MEDIA,
						'default' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'dynamic' => ['active' => true],
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__('Content', 'bdevs-elementor'),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => ['active' => true],
						'default'    => esc_html__('Its Content', 'bdevs-elementor'),
						'show_label' => true,
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__('Link Left Button', 'bdevs-elementor'),
						'type'        => Controls_Manager::URL,
						'dynamic'     => ['active' => true],
						'placeholder' => 'http://your-link.com',
						'default'     => [
							'url' => '#',
						],
					],
					[
						'name'        => 'tab_button_text',
						'label'       => esc_html__('Button Text', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('Make Appointment', 'bdevs-elementor'),
						'placeholder' => esc_html__('Make Appointment', 'bdevs-elementor'),
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__('Layout', 'bdevs-elementor'),
			]
		);


		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__('Show BG Image', 'bdevs-elementor'),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Register styles related controls
	 */
	protected function register_style_controls()
	{
		$this->main_section_style();
		$this->title_style_controls();
		$this->tab_button1_style();
		$this->tab_button2_style();
		$this->tab_button3_style();
		$this->button_style_controls();
	}


	protected function main_section_style()
	{

		$this->start_controls_section(
			'_section_style_section',
			[
				'label' => __('Section', 'bdevselement'),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'sec_margin',
			[
				'label' => __('Margin', 'bdevselement'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'sec_padding',
			[
				'label' => __('Padding', 'bdevselement'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'sec_background',
				'selector' => '{{WRAPPER}} .bdevs-el-section',
				'exclude' => [
					'image'
				]
			]
		);

		$this->end_controls_section();
	}

	// title_style_controls
	protected function title_style_controls()
	{
		$this->start_controls_section(
			'_section_style_content',
			[
				'label' => __('Title / Content', 'bdevs-elementor'),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		// Title
		$this->add_control(
			'_heading_title',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Title', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_responsive_control(
			'title_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title',
				'selector' => '{{WRAPPER}} .bdevs-el-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'color: {{VALUE}} !important',
				],
			]
		);


		// Subtitle
		$this->add_control(
			'_heading_subtitle',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Subtitle', 'bdevs-elementor'),
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'subtitle_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'color: {{VALUE}}',
				],

			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle',
				'selector' => '{{WRAPPER}} .bdevs-el-subtitle',

			]
		);

		// description
		$this->add_control(
			'_content_description',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Description', 'bdevs-elementor'),
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'description_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-desc' => 'margin-bottom: {{SIZE}}{{UNIT}} !important;',
				],
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-desc' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'description',
				'selector' => '{{WRAPPER}} .bdevs-el-desc',
			]
		);

		$this->end_controls_section();
	}

	protected function tab_button1_style()
	{
		$this->start_controls_section(
			'section_style_tabbutton1',
			[
				'label' => __('Tab Button 1', 'bdevs-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'tabbutton1_padding',
			[
				'label' => __('Padding', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'tabbutton1_border-radius',
			[
				'label' => __('Content Border Radius', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'tabbutton1_border',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tabbutton1-title',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link h6',
			]
		);

		$this->add_control(
			'tabbutton1_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link h6' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'tabbutton1_background',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(1) a.nav-link, .analysis-area .nav-item:nth-child(1) a.nav-link::after',
				'exclude' => [
					'image'
				]
			]
		);

		$this->end_controls_section();
	}

	protected function tab_button2_style()
	{
		$this->start_controls_section(
			'section_style_tabbutton2',
			[
				'label' => __('Tab Button 2', 'bdevs-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'tabbutton2_padding',
			[
				'label' => __('Padding', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'tabbutton2_border-radius',
			[
				'label' => __('Content Border Radius', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'tabbutton2_border',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tabbutton2-title',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link h6',
			]
		);

		$this->add_control(
			'tabbutton2_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link h6' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'tabbutton2_background',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(2) a.nav-link, .analysis-area .nav-item:nth-child(2) a.nav-link::after',
				'exclude' => [
					'image'
				]
			]
		);

		$this->end_controls_section();
	}

	protected function tab_button3_style()
	{
		$this->start_controls_section(
			'section_style_tabbutton3',
			[
				'label' => __('Tab Button 3', 'bdevs-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'tabbutton3_padding',
			[
				'label' => __('Padding', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'tabbutton3_border-radius',
			[
				'label' => __('Content Border Radius', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'tabbutton3_border',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tabbutton3-title',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link h6',
			]
		);

		$this->add_control(
			'tabbutton3_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link h6' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'tabbutton3_background',
				'selector' => '{{WRAPPER}} .analysis-area ul li.nav-item:nth-child(3) a.nav-link, .analysis-area .nav-item:nth-child(3) a.nav-link::after',
				'exclude' => [
					'image'
				]
			]
		);

		$this->end_controls_section();
	}


	// button_style_controls
	protected function button_style_controls()
	{
		$this->start_controls_section(
			'_section_style_button',
			[
				'label' => __('Button', 'bdevs-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __('Padding', 'bdevs-elementor'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .tp-el-btn',
				'scheme' => Typography::TYPOGRAPHY_4,
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'selector' => '{{WRAPPER}} .tp-el-btn',
			]
		);

		$this->add_control(
			'button_border_radius',
			[
				'label' => __('Border Radius', 'bdevs-elementor'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .tp-el-btn',
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);

		$this->start_controls_tabs('_tabs_button');

		$this->start_controls_tab(
			'_tab_button_normal',
			[
				'label' => __('Normal', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label' => __('Background Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'_tab_button_hover',
			[
				'label' => __('Hover', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_bg_color',
			[
				'label' => __('Background Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __('Border Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'button_border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();
	}


	public function render()
	{

		$settings  = $this->get_settings_for_display();
		extract($settings);

?>

		<!-- analysis-area start -->
		<section class="analysis-area pos-rel bdevs-el-section theme-bg pb-90">
			<?php if (!empty($settings['show_image'])) : ?>
				<div class="analysis-bg-icon">
					<img src="<?php print get_template_directory_uri(); ?>/img/analysis/analysis-bg-icon.png" alt="">
				</div>
			<?php endif; ?>
			<div class="container">
				<div class="row">
					<div class="col-xl-12">
						<ul class="nav nav-pills mb-65" id="pills-tab" role="tablist">
							<?php $counter = 1; ?>
							<?php foreach ($settings['analysis_tabs'] as  $key => $item) : ?>
								<?php
								$tab_active = ($key == 0) ? 'active' : '';
								?>

								<?php
								if ('' !== $item['tab_image_icon']) :
									$image_src = wp_get_attachment_image_src($item['tab_image_icon']['id'], 'full');
									$image_icon = $image_src ? $image_src[0] : '';
								?>
								<?php
								endif; ?>
								<li class="nav-item">
									<a class="nav-link <?php print $tab_active; ?>" id="pills-home-<?php print esc_attr($key); ?>" data-toggle="pill" href="#pills-<?php print esc_attr($key); ?>" role="tab" aria-controls="pills-<?php print esc_attr($key); ?>" aria-selected="true">

										<img src="<?php print esc_url($image_icon); ?>" alt="">
										<h6 class="bdevs-el-subtitle"><?php echo wp_kses_post($item['analysis_menu']); ?></h6>

									</a>
								</li>
							<?php
								$counter++;
							endforeach;
							?>
						</ul>
					</div>
				</div>
				<div class="row">
					<div class="col-xl-12">
						<div class="tab-content" id="pills-tabContent">
							<?php $counter_content = 1; ?>
							<?php foreach ($settings['analysis_tabs'] as  $key => $item) : ?>

								<?php
								$tab_pane_active = ($key == 0) ? 'show active' : '';
								$this->add_render_attribute(
									[
										'wedo-link' => [
											'class' => [
												'btn btn-icon tp-el-btn ml-0',
											],
											'href'   => $item['tab_link']['url'] ? esc_url($item['tab_link']['url']) : '#',
											'target' => $item['tab_link']['is_external'] ? '_blank' : '_self'
										]
									],
									'',
									'',
									true
								);
								if ('' !== $item['tab_image']) :
									$image_src = wp_get_attachment_image_src($item['tab_image']['id'], 'full');
									$image = $image_src ? $image_src[0] : '';
								?>
								<?php
								endif; ?>
								<div class="tab-pane fade  <?php print $tab_pane_active; ?>" id="pills-<?php print esc_attr($key); ?>" role="tabpanel" aria-labelledby="pills-home-<?php print esc_attr($key); ?>">
									<div class="row">
										<div class="col-xl-6 col-lg-8">
											<div class="section-title pos-rel mb-40">
												<div class="section-text section-text-white section-text-green pos-rel">
													<?php if (!empty($item['tab_sub_title'])) : ?>
														<h5 class="bdevs-el-subtitle">
															<?php echo wp_kses_post($item['tab_sub_title']); ?>
														</h5>
													<?php endif; ?>

													<?php if (!empty($item['tab_title'])) : ?>
														<h2 class="sec-title white-color bdevs-el-title"><?php echo wp_kses_post($item['tab_title']); ?></h2>
													<?php endif; ?>

													<?php if (!empty($item['tab_content'])) : ?>
														<p class="bdevs-el-desc">
															<?php echo $this->parse_text_editor($item['tab_content']); ?>
														</p>
													<?php endif; ?>
												</div>
											</div>
											<div class="section-button section-button-left mb-30">
												<?php if (!empty($item['tab_link']['url'])) : ?>
													<a <?php echo $this->get_render_attribute_string('wedo-link'); ?>>
														<span><?php print esc_html_e('+', 'bdevs-elementor'); ?> </span> <?php echo wp_kses_post($item['tab_button_text']); ?>
													</a>
												<?php endif; ?>
											</div>
										</div>
										<div class="col-xl-6 col-lg-4">
											<div class="analysis-chart mb-30">
												<img src="<?php print esc_url($image); ?>" alt="">
											</div>
										</div>
									</div>
								</div>
							<?php
								$counter_content++;
							endforeach;
							?>
						</div>
					</div>
				</div>
			</div>
		</section>
		<!-- analysis-area end -->

<?php
	}
}
