<?php

namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use \Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsChallenge extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'bdevs-challenge';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Challenge Area', 'bdevs-elementor');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['bdevs-elementor'];
	}

	public function get_keywords()
	{
		return ['challenge'];
	}

	public function get_script_depends()
	{
		return ['bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position()
	{
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor'),
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor'),
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor'),
			'center'        => esc_html__('Center', 'bdevs-elementor'),
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor'),
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor'),
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor'),
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor'),
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor'),
		];

		return $position_options;
	}

	// register_controls
	protected function register_controls()
	{
		$this->register_content_controls();
		$this->register_style_controls();
	}

	// register_content_controls
	protected function register_content_controls()
	{

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__('Section Heading', 'bdevs-elementor'),
				// 'condition' => [
				// 	'chose_style' => 'service_icon',
				// ],
			]
		);
		$this->add_control(
			'sub_heading',
			[
				'label'       => __('Sub Heading', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __('Enter your prefix Heading', 'bdevs-elementor'),
				'default'     => __('Awesome Features', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __('Heading', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __('Enter your heading', 'bdevs-elementor'),
				'default'     => __('It is Heading', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label' => __('Title HTML Tag', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'h1' => [
						'title' => __('H1', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h1'
					],
					'h2' => [
						'title' => __('H2', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h2'
					],
					'h3' => [
						'title' => __('H3', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h3'
					],
					'h4' => [
						'title' => __('H4', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h4'
					],
					'h5' => [
						'title' => __('H5', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h5'
					],
					'h6' => [
						'title' => __('H6', 'bdevs-elementor'),
						'icon' => 'eicon-editor-h6'
					]
				],
				'default' => 'h2',
				'toggle' => false,
			]
		);

		$this->add_control(
			'link_text',
			[
				'label'       => esc_html__('Button Text', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__('Make Appointment', 'bdevs-elementor'),
				'placeholder' => esc_html__('Link Text', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __('Link', 'bdevs-elementor'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'bdevs-elementor'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_features',
			[
				'label' => esc_html__('Counter', 'bdevs-elementor'),
			]
		);


		$this->add_control(
			'tabs',
			[
				'label' => esc_html__('Counter Items', 'bdevs-elementor'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__('Fact One', 'bdevs-elementor'),
						'tab_content' => esc_html__('Project Complate', 'bdevs-elementor'),
					],
					[
						'tab_title'   => esc_html__('Fact Two', 'bdevs-elementor'),
						'tab_content' => esc_html__('Project Complate', 'bdevs-elementor'),
					],
				],
				'fields' => [
					[
						'name'        => 'tab_number',
						'label'       => esc_html__('Fact Number', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('1M', 'bdevs-elementor'),
						'label_block' => true,
					],

					[
						'name'        => 'tab_title',
						'label'       => esc_html__('Title', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_html__('Satisfied Patients', 'bdevs-elementor'),
						'label_block' => true,
					],

					[
						'name'        => 'tab_icon',
						'label'       => esc_html__('Title', 'bdevs-elementor'),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => ['active' => true],
						'default'     => esc_attr__('fas fa-user', 'bdevs-elementor'),
						'label_block' => true,
					],

					[
						'name'       => 'tab_content',
						'label'      => esc_html__('Content', 'bdevs-elementor'),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => ['active' => true],
						'default'    => esc_html__('Counter Text', 'bdevs-elementor'),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__('Layout', 'bdevs-elementor'),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__('Alignment', 'bdevs-elementor'),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-right',
					],
					'justify' => [
						'title' => esc_html__('Justified', 'bdevs-elementor'),
						'icon'  => 'eicon-text-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Register styles related controls
	 */
	protected function register_style_controls()
	{
		$this->title_style_controls();
		$this->counter_box_style_controls();
		$this->button_style_controls();
	}


	// title_style_controls
	protected function title_style_controls()
	{
		$this->start_controls_section(
			'_section_style_content',
			[
				'label' => __('Title / Content', 'bdevs-elementor'),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => __('Content Padding', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_border-radius',
			[
				'label' => __('Content Border Radius', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'content_border',
				'selector' => '{{WRAPPER}} .bdevs-el-content',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'content_background',
				'selector' => '{{WRAPPER}} .bdevs-el-content',
				'exclude' => [
					'image'
				]
			]
		);

		// Title
		$this->add_control(
			'_heading_title',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Title', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_responsive_control(
			'title_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title',
				'selector' => '{{WRAPPER}} .bdevs-el-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'color: {{VALUE}}',
				],
			]
		);


		// Subtitle
		$this->add_control(
			'_heading_subtitle',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Subtitle', 'bdevs-elementor'),
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'subtitle_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'color: {{VALUE}}',
				],

			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle',
				'selector' => '{{WRAPPER}} .bdevs-el-subtitle',

			]
		);

		$this->end_controls_section();
	}

	// button_style_controls
	protected function button_style_controls()
	{
		$this->start_controls_section(
			'_section_style_button',
			[
				'label' => __('Button', 'bdevs-elementor'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __('Padding', 'bdevs-elementor'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .tp-el-btn',
				'scheme' => Typography::TYPOGRAPHY_4,
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'selector' => '{{WRAPPER}} .tp-el-btn',
			]
		);

		$this->add_control(
			'button_border_radius',
			[
				'label' => __('Border Radius', 'bdevs-elementor'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .tp-el-btn',
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);

		$this->start_controls_tabs('_tabs_button');

		$this->start_controls_tab(
			'_tab_button_normal',
			[
				'label' => __('Normal', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label' => __('Background Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'_tab_button_hover',
			[
				'label' => __('Hover', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_bg_color',
			[
				'label' => __('Background Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __('Border Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'button_border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .tp-el-btn:hover, {{WRAPPER}} .tp-el-btn:focus' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();
	}


	// counter_box_style_controls
	protected function counter_box_style_controls()
	{
		$this->start_controls_section(
			'_section_style_counter_box',
			[
				'label' => __('Counter Box', 'bdevs-elementor'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		// Number
		$this->add_control(
			'_heading_number_title',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Number', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'number_title_spacing',
			[
				'label' => __('Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'number_title_color',
			[
				'label' => __('Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-number' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'number_title',
				'selector' => '{{WRAPPER}} div.bdevs-el-fact-number',
			]
		);

		// Number Title
		$this->add_control(
			'_heading_number_titles',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Number Title', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_control(
			'number_titles_spacing',
			[
				'label' => __('Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-number-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'number_title_colors',
			[
				'label' => __('Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-number-title' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'number_titles',
				'selector' => '{{WRAPPER}} div.bdevs-el-fact-number-title',
			]
		);

		// description
		$this->add_control(
			'_content_number_description',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Description', 'bdevs-elementor'),
				'separator' => 'before',

			]
		);

		$this->add_responsive_control(
			'number_description_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-des' => 'margin-bottom: {{SIZE}}{{UNIT}} !important;',
				],

			]
		);

		$this->add_control(
			'number_description_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-fact-des' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'number_description',
				'selector' => '{{WRAPPER}} .bdevs-el-fact-des',

			]
		);

		$this->end_controls_section();
	}


	public function render()
	{
		$settings  = $this->get_settings_for_display();

		extract($settings);

		$this->add_inline_editing_attributes('heading', 'basic');
		$this->add_render_attribute('heading', 'class', 'sec-title white-text bdevs-el-title');

		$this->add_render_attribute(
			[
				'link' => [
					'class' => [
						'btn btn-icon ml-0 tp-el-btn',
					],
					'href'   => $settings['link']['url'] ? esc_url($settings['link']['url']) : '#',
					'target' => $settings['link']['is_external'] ? '_blank' : '_self'
				]
			],
			'',
			'',
			true
		);
?>

		<section class="fact-area fact-map pos-rel bdevs-el-content">
			<div class="container">
				<div class="row">
					<div class="col-xl-6 col-lg-6 col-md-10">
						<div class="section-title pos-rel mb-45">
							<div class="section-text section-text-white pos-rel">
								<?php if (!empty($settings['sub_heading'])) : ?>
									<h5 class="bdevs-el-subtitle"><?php echo wp_kses_post($settings['sub_heading']); ?></h5>
								<?php endif; ?>

								<?php if ($settings['heading']) :
									printf(
										'<%1$s %2$s>%3$s</%1$s>',
										tag_escape($settings['title_tag']),
										$this->get_render_attribute_string('heading'),
										wp_kses_post($settings['heading'])
									);
								endif; ?>

							</div>
						</div>

						<?php if ((!empty($settings['link']['url']))) : ?>
							<div class="section-button section-button-left mb-30 xxxx">
								<a <?php echo $this->get_render_attribute_string('link'); ?>>
									<span>+</span> <?php echo esc_html($settings['link_text']); ?>
								</a>
							</div>
						<?php endif; ?>
					</div>
					<div class="col-lg-6 col-lg-6 col-md-8">
						<div class="cta-satisfied">
							<?php
							foreach ($settings['tabs'] as $item) : ?>
								<div class="single-satisfied mb-50">
									<?php
									if (!empty($item['tab_number'])) : ?>
										<h2 class="counter-title bdevs-el-fact-number "><?php echo wp_kses_post($item['tab_number']); ?></h2>
									<?php endif; ?>

									<?php
									if (!empty($item['tab_title'])) : ?>
										<h5 class="bdevs-el-fact-number-title"><i class="<?php echo wp_kses_post($item['tab_icon']); ?>"></i> <?php echo wp_kses_post($item['tab_title']); ?></h5>
									<?php endif; ?>

									<?php
									if (!empty($item['tab_content'])) : ?>
										<p class="bdevs-el-fact-des"><?php echo wp_kses_post($item['tab_content']); ?></p>
									<?php endif; ?>
								</div>
							<?php
							endforeach;
							?>
						</div>
					</div>
				</div>
			</div>
		</section>

<?php
	}
}
