<?php

namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use \Elementor\Core\Schemes\Typography;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMission extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'bdevs-mission';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Mission', 'bdevs-elementor');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['bdevs-elementor'];
	}

	public function get_keywords()
	{
		return ['mission', 'vision'];
	}

	public function get_script_depends()
	{
		return ['bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position()
	{
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor'),
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor'),
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor'),
			'center'        => esc_html__('Center', 'bdevs-elementor'),
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor'),
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor'),
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor'),
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor'),
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor'),
		];

		return $position_options;
	}

	// register_controls
	protected function register_controls()
	{
		$this->register_content_controls();
		$this->register_style_controls();
	}

	// register_content_controls
	protected function register_content_controls()
	{
		$this->start_controls_section(
			'section_content_features',
			[
				'label' => esc_html__('Mission', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __('Heading', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __('Enter your heading', 'bdevs-elementor'),
				'default'     => __('It is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);


		$this->add_control(
			'sub_heading',
			[
				'label'       => __('Sub Heading', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __('Enter your sub heading', 'bdevs-elementor'),
				'default'     => __('It is sub heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);



		$this->add_control(
			'desc',
			[
				'label'       => __('About Text', 'bdevs-elementor'),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __('Enter your about text', 'bdevs-elementor'),
				'default'     => __('About Content Here', 'bdevs-elementor'),
				'label_block' => true,
			]
		);


		$this->add_control(
			'image',
			[
				'label'   => esc_html__('Image', 'bdevs-elementor'),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'dynamic' => ['active' => true],
				'description' => esc_html__('Add Your Mission Image', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'   => esc_html__('Icon', 'bdevs-elementor'),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'dynamic' => ['active' => true],
				'description' => esc_html__('Add Your Mission Icon', 'bdevs-elementor'),
			]
		);


		$this->end_controls_section();

		/** facts section **/
		$this->start_controls_section(
			'facts_section',
			[
				'label' => esc_html__('Facts', 'bdevs-elementor'),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__('Fact Items', 'bdevs-elementor'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__('Fact #1', 'bdevs-elementor'),
						'tab_content' => esc_html__('I am item content. Click edit button to change this text.', 'bdevs-elementor'),
					],
					[
						'tab_title'   => esc_html__('Fact #2', 'bdevs-elementor'),
						'tab_content' => esc_html__('I am item content. Click edit button to change this text.', 'bdevs-elementor'),
					],
				],
				'fields' => [
					[
						'name'        => 'icon',
						'label'       => esc_html__('Icon', 'bdevs-elementor'),
						'type'        => Controls_Manager::MEDIA,
						'default' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
						'dynamic'     => ['active' => true],
						'label_block' => true,
						'description' => esc_html__('Upload Icon from here', 'bdevs-elementor'),
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__('Content', 'bdevs-elementor'),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => ['active' => true],
						'show_label' => false,
					],
				],
			]
		);

		$this->end_controls_section();


		/** 
		 *	Layout section 
		 **/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__('Layout', 'bdevs-elementor'),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__('Alignment', 'bdevs-elementor'),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'bdevs-elementor'),
						'icon'  => 'eicon-h-align-right',
					],
					'justify' => [
						'title' => esc_html__('Justified', 'bdevs-elementor'),
						'icon'  => 'eicon-text-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_icon',
			[
				'label'   => esc_html__('Show icon Image', 'bdevs-elementor'),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Register styles related controls
	 */
	protected function register_style_controls()
	{
		$this->title_style_controls();
	}

	// title_style_controls
	protected function title_style_controls()
	{
		$this->start_controls_section(
			'_section_style_content',
			[
				'label' => __('Title / Content', 'bdevs-elementor'),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => __('Content Padding', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_border-radius',
			[
				'label' => __('Content Border Radius', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'content_border',
				'selector' => '{{WRAPPER}} .bdevs-el-content',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'content_background',
				'selector' => '{{WRAPPER}} .bdevs-el-content',
				'exclude' => [
					'image'
				]
			]
		);

		// Title
		$this->add_control(
			'_heading_title',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Title', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_responsive_control(
			'title_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title',
				'selector' => '{{WRAPPER}} .bdevs-el-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-title' => 'color: {{VALUE}}',
				],
			]
		);


		// Subtitle
		$this->add_control(
			'_heading_subtitle',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => __('Subtitle', 'bdevs-elementor'),
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'subtitle_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-subtitle' => 'color: {{VALUE}}',
				],

			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle',
				'selector' => '{{WRAPPER}} .bdevs-el-subtitle',

			]
		);

		// description
		$this->add_control(
			'_content_description',
			[
				'type' => Controls_Manager::HEADING,
				'label' => __('Description', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_responsive_control(
			'description_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-des' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __('Text Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-des' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description',
				'selector' => '{{WRAPPER}} .bdevs-el-des',
				'scheme' => Typography::TYPOGRAPHY_4,
			]
		);

		// mission_item
		$this->add_control(
			'_content_rating',
			[
				'type' => Controls_Manager::HEADING,
				'label' => __('Mission Item', 'bdevs-elementor'),
				'separator' => 'before'
			]
		);

		$this->add_responsive_control(
			'rating_spacing',
			[
				'label' => __('Bottom Spacing', 'bdevs-elementor'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-mission-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'rating_color',
			[
				'label' => __('Color', 'bdevs-elementor'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bdevs-el-mission-item' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rating',
				'selector' => '{{WRAPPER}} .bdevs-el-mission-item',
				'scheme' => Typography::TYPOGRAPHY_4,
			]
		);

		$this->end_controls_section();
	}



	public function render()
	{
		$settings  = $this->get_settings_for_display();
		extract($settings);
?>


		<section class="about-area bdevs-el-content">
			<div class="container">
				<div class="row">
					<div class="col-xl-6 col-lg-10 col-md-12">
						<div class="about-title mb-20">

							<?php
							if (!empty($sub_heading)) : ?>
								<h5 class="bdevs-el-subtitle"><?php echo wp_kses_post($sub_heading); ?></h5>
							<?php
							endif; ?>

							<?php
							if (!empty($heading)) : ?>
								<h2 class="sec-title bdevs-el-title"><?php echo wp_kses_post($heading); ?></h2>
							<?php
							endif; ?>
						</div>
						<div class="about-text mission-about-text">
							<p class="bdevs-el-des"><?php echo wp_kses_post($settings['desc']); ?></p>
						</div>
						<div class="mission-vision-list pr-90">
							<?php foreach ($settings['tabs'] as $item) :
								extract($item);
							?>
								<div class="mv-single-list d-flex">
									<?php
									if ('' !== $icon['id']) :
										$image_src = wp_get_attachment_image_src($icon['id'], 'full');
										$image_url = $image_src ? $image_src[0] : '';
									?>
										<div class="mv-icon">
											<img src="<?php print esc_url($image_url); ?>" alt="<?php print wp_kses_post($tab_title); ?>">
										</div>
									<?php
									endif;
									?>

									<?php
									if (!empty($tab_content)) : ?>
										<div class="mv-text">
											<p class="bdevs-el-mission-item"><?php print wp_kses_post($this->parse_text_editor($tab_content)); ?></p>
										</div>
									<?php endif; ?>
								</div>
							<?php
							endforeach;
							?>
						</div>
					</div>
					<div class="col-xl-6 col-lg-6 d-lg-none d-xl-block">

						<?php if ('' !== $settings['image']) :
							$image_src = wp_get_attachment_image_src($settings['image']['id'], 'full');
							$image = $image_src ? $image_src[0] : '';
						?>
							<div class="mv-right-img pos-rel mb-30">
								<img src="<?php print esc_url($image); ?>" alt="">
							</div>
						<?php endif; ?>


						<?php if ($settings['show_icon']) : ?>
							<?php if ('' !== $settings['icon']) :
								$icon_src = wp_get_attachment_image_src($settings['icon']['id'], 'full');
								$icon_url = $icon_src ? $icon_src[0] : '';
							?>
								<div class="testi-quato-icon about-icon-white d-none d-xl-block">
									<img src="<?php print esc_url($icon_url); ?>" alt="">
								</div>
							<?php endif; ?>
						<?php endif; ?>
					</div>
				</div>
			</div>
		</section>
<?php
	}
}
